@@ -203,6 +203,8 @@ if ($do==1) {
       ($stdout,$stderr)=$handle->cmd('sudo yum -y install uuid-devel '.
          'pkgconfig libtool gcc-c++','__display__');
    }
+   ($stdout,$stderr)=$handle->cmd("mkdir -vp FullAutoAPI/deps",'__display__');
+   ($stdout,$stderr)=$handle->cwd("FullAutoAPI/deps");
    ($stdout,$stderr)=$handle->cmd(
       "wget --random-wait --progress=dot ".
       "https://github.com/jedisct1/libsodium/archive/master.zip",
@@ -318,7 +320,7 @@ if ($do==1) {
 exit;
 }
    if ($^O eq 'cygwin') {
-      ($stdout,$stderr)=$handle->cwd("~");
+      #($stdout,$stderr)=$handle->cwd("~");
       $handle->{_cmd_handle}->print('cpan');
    } else {
       ($stdout,$stderr)=$handle->cmd('sudo yum -y install cpan',
@@ -488,7 +490,6 @@ END
       SQL::Translator
       Template::Alloy
       URI::Amazon::APA 
-      TheSchwartz
       Devel::CheckLib
       Catalyst::Runtime
       Proc::ProcessTable
@@ -966,25 +967,9 @@ END
          next;
       }
    }
-   ($stdout,$stderr)=$handle->cmd("catalyst.pl Hello",'__display__');
-   ($stdout,$stderr)=$handle->cwd("Hello");
-   ($stdout,$stderr)=$handle->cmd("perl Makefile.PL",'__display__');
-   #$handle->{_cmd_handle}->print(
-   #   'script/hello_server.pl --background');
-   #$prompt=substr($handle->{_cmd_handle}->prompt(),1,-1);
-   #while (1) {
-   #   my $output.=Net::FullAuto::FA_Core::fetch($handle);
-   #   last if $output=~/$prompt/;
-   #   print $output;
-   #   if (-1<index $output,'| /end') {
-   #      $output=Net::FullAuto::FA_Core::fetch($handle);
-   #      print $output;
-   #      last;
-   #   }
-   #}
    ($stdout,$stderr)=$handle->cwd("..");
    ($stdout,$stderr)=$handle->cmd("catalyst.pl FullAutoAPI",'__display__');
-   ($stdout,$stderr)=$handle->cwd("FullAutoAPI");
+   #($stdout,$stderr)=$handle->cwd("FullAutoAPI");
    ($stdout,$stderr)=$handle->cmd("perl Makefile.PL",'__display__');
    my $pm_path="./lib/FullAutoAPI.pm";
    $ad="    Session%NL%".
@@ -1145,6 +1130,7 @@ END
    ($stdout,$stderr)=$handle->cmd("${sudo}sed -i \"s/%SQ%/\'/g\" $user_path");
    ($stdout,$stderr)=$handle->cmd("./script/fullautoapi_create.pl ".
       "controller OAuth2::Provider",'__display__');
+   ($stdout,$stderr)=$handle->cwd("deps");
    ($stdout,$stderr)=$handle->cmd("wget -qO- http://libevent.org/");
    $stdout=~/^.*Stable releases.*?href=["](.*?)["].*?href=["](.*?)["].*$/s;
    my $le_rel=$1;my $le_asc=$2;
@@ -1181,7 +1167,7 @@ END
       "'s#{ \"cache_redzone#// { \"cache_redzone#' testapp.c");
    ($stdout,$stderr)=$handle->cmd("make",'__display__');
    ($stdout,$stderr)=$handle->cmd("make install",'__display__'); 
-   ($stdout,$stderr)=$handle->cwd("..");
+   ($stdout,$stderr)=$handle->cwd("../..");
    #
    # echo-ing/streaming files over ssh can be tricky. Use echo -e
    #          and replace these characters with thier HEX
@@ -1302,7 +1288,6 @@ package FullAutoAPI::Controller::User;
 use strict;
 use warnings;
 use Moose;
-use TheSchwartz::Job;
 use DBI;
 use namespace::autoclean;
 use ZMQ::LibZMQ4;
@@ -1658,28 +1643,6 @@ CREATE TABLE exitstatus (
         delete_after INTEGER UNSIGNED
 );
 END
-   ($stdout,$stderr)=$handle->cwd('../db');
-   ($stdout,$stderr)=$handle->cmd(
-      "echo \"$theswartz_schema\" | sqlite3 theschwartz.sqlt");
-   ($stdout,$stderr)=$handle->cwd('..');
-   ($stdout,$stderr)=$handle->cmd(
-      "./script/fullautoapi_create.pl model TheSchwartz",'__display__');
-   $ad='__PACKAGE__->config( class => "TheSchwartz" );%NL%%NL%'. # %NL% is newline
-      'sub mangle_arguments { %{ $_[1]->{args} } }%NL%';
-   ($stdout,$stderr)=$handle->cmd(
-      "${sudo}sed -i \'/Catalyst::Model/a$ad\' ".
-      "./lib/FullAutoAPI/Model/TheSchwartz.pm");
-   ($stdout,$stderr)=$handle->cmd( # bash shell specific
-      "${sudo}sed -i \'s/%NL%/\'\"`echo \\\\\\n`/g\" ".
-      "./lib/FullAutoAPI/Model/TheSchwartz.pm");
-   $content=<<END;
-Model::TheSchwartz:
-  args:
-    verbose: 1
-    databases:
-      - dsn: dbi:SQLite:__path_to(db/theschwartz.sqlt)__
-END
-   ($stdout,$stderr)=$handle->cmd("echo \"$content\" >> fullautoapi.yml");
    $ad="use Net::FullAuto;%NL%".
        "use ZMQ::LibZMQ4;%NL%".
        "use ZMQ::Constants qw(:all);%NL%".
@@ -1695,6 +1658,8 @@ END
        "%NL%".
        "use Parallel::Forker;%NL%".
        "%NL%".
+       "system(\"/usr/local/bin/memcached &\");%NL%".
+       "%NL%".
        "my \$fa_sub=sub {%NL%".
        "%NL%".
        "   my \$server={%NL%".
@@ -1893,33 +1858,6 @@ END
       "./script/fullautoapi_server.pl");
    ($stdout,$stderr)=$handle->cmd("${sudo}sed -i \"s/%SQ%/\'/g\" ".
       "./script/fullautoapi_server.pl");
-   ($stdout,$stderr)=$handle->cwd("..");
-   ($stdout,$stderr)=$handle->put("fullauto.pem");
-   ($stdout,$stderr)=$handle->cmd(
-      "wget --random-wait --progress=dot ".
-      "https://github.com/pangyre/p5-myapp-10in10/archive/master.zip",
-      '__display__');
-   ($stdout,$stderr)=$handle->cmd("unzip master.zip",'__display__');
-   ($stdout,$stderr)=$handle->cmd("rm -rvf master.zip",'__display__');
-   ($stdout,$stderr)=$handle->cwd("p5-myapp-10in10-master");
-   print "\n\n   p5-myapp-10in10-master CWD ERROR => $stderr\n\n"
-      if $stderr;
-   ($stdout,$stderr)=$handle->cmd("mkdir -vp root/static/img/title",
-      '__display__');
-   ($stdout,$stderr)=$handle->cmd("perl Makefile.PL",'__display__');
-   ($stdout,$stderr)=$handle->cmd(
-      "sed -i 's/static.*=/Plugin::Static::Simple =/' lib/MyApp.pm");
-   ($stdout,$stderr)=$handle->cmd(
-      "sed -i \"s/Plugin::Static::Simple/'&'/\" lib/MyApp.pm");
-   ($stdout,$stderr)=$handle->cmd(
-      "sed -i '/Unicode::Encoding/d' lib/MyApp.pm");
-   $ad='encoding: utf8';
-   ($stdout,$stderr)=$handle->cmd(
-      "sed -i \'/default_view/a $ad\' myapp.yml");
-print "GOING TO START MYAPP SERVER\n";
-   $handle->{_cmd_handle}->print(
-      'script/myapp_server.pl --background');
-   ($stdout,$stderr)=$handle->cwd("../FullAutoAPI");
    ($stdout,$stderr)=$handle->cmd("${sudo}ldconfig");
 print "GOING TO START WEB SERVER\n";
    $handle->{_cmd_handle}->print(
